/*-------------------------------------------------------------------------+
| Copyright 2021 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.service;

import java.util.List;

import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.service.base.IEObjectAware;

/**
 * Interface for DependingElementProviders that can be registered in the {@link IDependingElementProviderService}.
 * 
 * @author bayha
 *
 * @param <T>	The subclass of {@link EObject} for which this provider shall be invoked. 
 */
public interface IDependingElementProvider<T extends EObject> extends IEObjectAware<T> {
	
	/**
	 * Retrieves the {@link EObject}s which depend on the given {@link EObject}.  
	 * 
	 * @param elem	The {@link EObject} to retrieve elements which depend on it.
	 * @return		The {@link List} of {@link EObject} which depend on elem.
	 */
	public List<EObject> getDependingElements(EObject elem);
}
