/*-------------------------------------------------------------------------+
| Copyright 2021 fortiss GmbH                                              |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+--------------------------------------------------------------------------*/
package org.fortiss.tooling.ext.variability.service;

import java.util.List;


import org.eclipse.emf.ecore.EObject;
import org.fortiss.tooling.kernel.introspection.IIntrospectiveKernelService;
/**
 * Interface of the DependingElementProviderService which resolves semantic
 * and syntactic dependencies between model elements.
 * 
 * @author bayha
 */
public interface IDependingElementProviderService extends IIntrospectiveKernelService {

	/** Name of the respective extension point. */
	/* package */static final String EXTENSION_POINT_NAME = "org.fortiss.af3.variability.dependingElementProvider";
	/** Name of the respective configuration element. */
	/* package */ static final String CONFIGURATION_ELEMENT_NAME = "dependingElementProvider";

	/** Retrieves the singleton instance of this service. */
	public static IDependingElementProviderService getInstance() {
		return DependingElementProviderService.getInstance();
	}

	/**
	 * Retrieves all depending elements for the given {@link EObject}.
	 * 
	 * @param obj	The {@link EObject} to retrieve the elements which depend on it.
	 * @return		The {@link List} of {@link EObject} which depend on the obj.
	 */
	public List<EObject> getDependingElements(EObject obj);
	
	/**
	 * Registers the given {@link IDependingElementProvider} in this service.  
	 * 
	 * @param provider	The {@link IDependingElementProvider} to register.
	 * @param cls		The subclass of {@link EObject} the given provider shall be used for.
	 */
	public void registerDependingElementProvider(IDependingElementProvider<? extends EObject> provider, Class<? extends EObject> cls);
}
